# Python move my mouse 


## Description
This script will move the mouse for you, when you are not at the desk:
> MS Teams changes your online status after certain minutes, which is kinda annoying,   
> when you watch a Video or if you read a long text ;-)   

## Installation
> I recommend to use the [pipx](https://pypi.org/project/pipx/) installer,   
> to install the package isolated from your global python installation.  



```commandline
pipx install sat_mouse_mover
```

## Usage
After you installed the package, there is a CLI command available
```commandline
sat_mouse_watch
```
